@@ -19,4 +19,8 @@ class TelegramBot(Service):
 
     def send_message(self, message: str) -> None:
         url = f"https://api.telegram.org/bot{self.TOKEN}/sendMessage?chat_id={self.CHAT_ID}&text={message}"
-        print(requests.get(url).json()) # this sends the message
\ No newline at end of file
+        print(requests.get(url).json()) # this sends the message
+
+    def send_image(self, filename: str) -> None:
+        file = { 'photo': open(filename, 'rb') }
+        resp = requests.post()
\ No newline at end of file
