@@ -14,8 +14,8 @@ class Parser:
     def click(self, path: str, element: any=None, timeout: int=0, pos: int=0, is_error: bool=True) -> any:
         return self.scraper.click(path=path, element=element, timeout=timeout, pos=pos, is_error=is_error)
 
-    def hover(self, path: str, element: any=None, is_error: bool=True) -> None:
-        self.scraper.hover(path=path, element=element, is_error=is_error)
+    def hover(self, path: str, element: any=None, is_error: bool=True, timeout: int=0) -> None:
+        self.scraper.hover(path=path, element=element, is_error=is_error, timeout=timeout)
 
     def click_and_hold(self, path: str, seconds: float, element: any=None, timeout: int=0, is_error: bool=True) -> None:
         return self.scraper.click_and_hold(path=path, element=element, timeout=timeout, seconds=seconds, is_error=is_error)
