@@ -12,7 +12,7 @@ from selenium.common.exceptions import NoSuchElementException
 from selenium.common.exceptions import StaleElementReferenceException
 from selenium.webdriver.common.action_chains import ActionChains
 from selenium.webdriver.remote.remote_connection import LOGGER
-# import undetected_chromedriver.v2 as uc
+import undetected_chromedriver as uc
 
 import logging
 import platform
@@ -26,13 +26,13 @@ class Selenium(Scraper):
 
         if user_dir is None or url is not None:
             options = webdriver.ChromeOptions()
-        # else:
-        #     options = uc.ChromeOptions()
+        else:
+            options = uc.ChromeOptions()
 
-        #     # another way to set profile is the below (which takes precedence if both variants are used
-        #     options.add_argument(f'--user-data-dir={user_dir}')
-        #     # just some options passing in to skip annoying popups
-        #     options.add_argument('--no-first-run --no-service-autorun --password-store=basic')            
+            # another way to set profile is the below (which takes precedence if both variants are used
+            options.add_argument(f'--user-data-dir={user_dir}')
+            # just some options passing in to skip annoying popups
+            options.add_argument('--no-first-run --no-service-autorun --password-store=basic')            
 
         #region options
         if fullscreen is True:
